
// (c) COPYRIGHT URI/MIT 1996,1997
// Please read the full copyright statement in the file COPYRIGH.  
//
// Authors:
//	reza		Reza Nekovei (reza@intcomm.net)

// This is the main CGI program which extracts DDS class descriptors from a
// DSP data file. In addition, the descriptors from an external file (if 
// exist, with the same name as the netCDF file and extension of .dds)  
// are extracted and added to the in-memory DDS table before it is sent 
// over the network to the client side. 
//
// ReZa 8/27/96

// $Log: dsp_dds.cc,v $
// Revision 1.7  1999/04/30 21:32:48  jimg
// Merged no-gnu and release-2-17
//
// Revision 1.6.8.1  1999/02/10 06:28:59  brent
// convert to Standard C++ strings -- b^2
//
// Revision 1.6  1998/03/20 00:29:52  jimg
// Changed calls to the set_mime_*() to match the new parameters
//
// Revision 1.5  1998/02/05 20:14:23  jimg
// DODS now compiles with gcc 2.8.x
//
// Revision 1.4  1997/07/15 17:53:40  jimg
// merged release-2-1-4 changes
//
// Revision 1.3.2.1  1997/07/15 00:50:06  jimg
// Fixed as per Dan's changes for version 2.14; changed the DAS and DDS objects
// so that the are pointers and not global static objects.
//
// Revision 1.3  1997/03/10 05:41:54  reza
// Added error objects to the code and updated for release 2.12.
// Now the data is sent gzip compressed.
//
// Revision 1.2  1996/11/15 18:22:31  jimg
// Fixed copyright statement.
// Added include of config header
//
// Revision 1.1  1996/09/18 22:42:28  reza
//  First release of DODS-DSP servers.
//
//

#include "config_dsp.h"

static char rcsid[]={"$Id: dsp_dds.cc,v 1.7 1999/04/30 21:32:48 jimg Exp $"};

#include <iostream.h>

#include "DDS.h"
#include "cgi_util.h"
#include "DODSFilter.h"

extern bool read_descriptors(DDS &dds, const string &filename, string *error);

int 
main(int argc, char *argv[])
{
    DDS dds;
    DODSFilter df(argc, argv);

    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
	df.send_version_info();
	return 0;
    }

    // Read the dataset descriptor in memory
    string errMsg;
    if (!read_descriptors(dds, df.get_dataset_name(), &errMsg)) {
	ErrMsgT("dsp_dds: could not read the DDS information");
	//client error message
	Error e(unknown_error, errMsg);
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
    }

    if (!df.read_ancillary_dds(dds))
	return 1;

    if (!df.send_dds(dds, true))
	return 1;

    return 0;
}
